@@ -13,7 +13,7 @@
 ** is not included in the SQLite library.  It is used for automated
 ** testing of the SQLite library.
 **
-** $Id: test8.c,v 1.40 2006/07/08 18:09:15 drh Exp $
+** $Id: test8.c,v 1.43 2006/10/08 18:56:57 drh Exp $
 */
 #include "sqliteInt.h"
 #include "tcl.h"
@@ -257,7 +257,7 @@ static int echoDeclareVtab(
   echo_vtab *pVtab, 
   sqlite3 *db, 
   int argc, 
-  char **argv
+  const char *const*argv
 ){
   int rc = SQLITE_OK;
 
@@ -311,8 +311,9 @@ static int echoDestructor(sqlite3_vtab *pVtab){
 static int echoConstructor(
   sqlite3 *db,
   void *pAux,
-  int argc, char **argv,
-  sqlite3_vtab **ppVtab
+  int argc, const char *const*argv,
+  sqlite3_vtab **ppVtab,
+  char **pzErr
 ){
   int i;
   echo_vtab *pVtab;
@@ -357,12 +358,13 @@ static int echoConstructor(
 static int echoCreate(
   sqlite3 *db,
   void *pAux,
-  int argc, char **argv,
-  sqlite3_vtab **ppVtab
+  int argc, const char *const*argv,
+  sqlite3_vtab **ppVtab,
+  char **pzErr
 ){
   int rc = SQLITE_OK;
   appendToEchoModule((Tcl_Interp *)(pAux), "xCreate");
-  rc = echoConstructor(db, pAux, argc, argv, ppVtab);
+  rc = echoConstructor(db, pAux, argc, argv, ppVtab, pzErr);
 
   /* If there were two arguments passed to the module at the SQL level 
   ** (i.e. "CREATE VIRTUAL TABLE tbl USING echo(arg1, arg2)"), then 
@@ -392,11 +394,12 @@ static int echoCreate(
 static int echoConnect(
   sqlite3 *db,
   void *pAux,
-  int argc, char **argv,
-  sqlite3_vtab **ppVtab
+  int argc, const char *const*argv,
+  sqlite3_vtab **ppVtab,
+  char **pzErr
 ){
   appendToEchoModule((Tcl_Interp *)(pAux), "xConnect");
-  return echoConstructor(db, pAux, argc, argv, ppVtab);
+  return echoConstructor(db, pAux, argc, argv, ppVtab, pzErr);
 }
 
 /* 
@@ -650,11 +653,12 @@ static int echoBestIndex(sqlite3_vtab *tab, sqlite3_index_info *pIdxInfo){
   for(ii=0; ii<pIdxInfo->nConstraint; ii++){
     const struct sqlite3_index_constraint *pConstraint;
     struct sqlite3_index_constraint_usage *pUsage;
+    int iCol;
 
     pConstraint = &pIdxInfo->aConstraint[ii];
     pUsage = &pIdxInfo->aConstraintUsage[ii];
 
-    int iCol = pConstraint->iColumn;
+    iCol = pConstraint->iColumn;
     if( pVtab->aIndex[iCol] ){
       char *zCol = pVtab->aCol[iCol];
       char *zOp = 0;
@@ -759,8 +763,8 @@ int echoUpdate(
 
   /* If apData[0] is an integer and nData>1 then do an UPDATE */
   if( nData>1 && sqlite3_value_type(apData[0])==SQLITE_INTEGER ){
-    z = sqlite3_mprintf("UPDATE %Q", pVtab->zTableName);
     char *zSep = " SET";
+    z = sqlite3_mprintf("UPDATE %Q", pVtab->zTableName);
 
     bindArgOne = (apData[1] && sqlite3_value_type(apData[1])==SQLITE_INTEGER);
     bindArgZero = 1;
